---
name: User story
about: This template provides a basic structure for user story issues.
title: ''
labels: ''
assignees: ''

---

# User story
As a ..., I want to ..., so I can ...

*Ideally, this is in the issue title, but if not, you can put it here. If so, delete this section.*

# Acceptance criteria
- [ ] This is something that can be verified to show that this user story is satisfied.

# Sprint Ready Checklist 
- [ ] 1. Acceptance criteria defined 
- [ ] 2. Team understands acceptance criteria 
- [ ] 3. Team has defined solution / steps to satisfy acceptance criteria 
- [ ] 4. Acceptance criteria is verifiable / testable 
- [ ] 5. External / 3rd Party dependencies identified
- [ ] 6. Ticket is prioritized and sized

# Notes
*Add any helpful notes here.*
